@@ -10,13 +10,6 @@ from mason import port
 from mason import schema
 from mason import storage
 
-try:
-    from importlib import metadata  # Python 3.8+
-except ImportError:
-    import importlib_metadata as metadata  # Python 3.7<
-
-__version__ = metadata.version('mason-framework')
-
 Blueprint = node.Blueprint
 Library = library.Library
 Event = events.Event
