@@ -47,12 +47,15 @@ def _dump_node(node_inst: node.Node) -> Dict[str, Any]:
         nodes[child_uid] = _convert_node_to_proto(child_node)
 
     values = {}
+    formats = {}
     connections = {}
     for port_ in node_inst.ports.values():
         if port_.direction == port.PortDirection.Input:
             if port_.local_value != port_.default:
                 values[port_.name] = json.dumps(port_.local_value,
                                                 default=_serialize)
+            if port_.value_format:
+                formats[port_.name] = port_.value_format
             targets = [conn.uid for conn in port_.connections]
             if targets:
                 conn = blueprint_pb2.Connection()
@@ -77,6 +80,8 @@ def _dump_node(node_inst: node.Node) -> Dict[str, Any]:
         props['label'] = node_inst._label
     if values:
         props['set'] = values
+    if formats:
+        props['formats'] = formats
     if connections:
         props['connect'] = connections
     return {f'{node_schema.group}.{node_schema.name}': props}
@@ -139,6 +144,7 @@ def _convert_port_schema_to_proto(
     return library_pb2.PortSchema(
         name=port_schema.name,
         type=port_schema.value_type,
+        format=port_schema.value_format,
         direction=port_schema.direction.value,
         sequence=port_schema.is_sequence,
         map=port_schema.is_map,
@@ -185,6 +191,9 @@ def _parse_node(
             _, child_connections = _parse_node(child_uid, child_info, new_node)
             node_connections.extend(child_connections)
 
+        for port_name, value_format in type_info.get('formats', {}).items():
+            new_node.ports[port_name].value_format = value_format
+
         for port_name, value_json in type_info.get('set', {}).items():
             try:
                 value = json.loads(value_json)
