@@ -1,5 +1,6 @@
 """Defines Node classes."""
 import contextlib
+import dataclasses
 import functools
 import inspect
 import uuid
@@ -7,7 +8,6 @@ import enum
 from typing import Any, Callable, Dict, Optional, Set, Sequence, TypeVar, Union
 from typing import Collection, Generator, Tuple, Type, TYPE_CHECKING
 
-import attr
 
 from mason import callbacks
 from mason import exceptions
@@ -24,7 +24,7 @@ if TYPE_CHECKING:
     from mason import middleware
 
 
-@attr.s(auto_attribs=True)
+@dataclasses.dataclass
 class ExecutionContext:
     """Context information when running a flow."""
 
@@ -33,7 +33,7 @@ class ExecutionContext:
     results: Dict[str, Any]
 
 
-@attr.s(auto_attribs=True)
+@dataclasses.dataclass
 class ErrorResult:
     """Captures error response information."""
 
@@ -42,7 +42,7 @@ class ErrorResult:
     trace: str = ''
 
 
-@attr.s(auto_attribs=True)
+@dataclasses.dataclass
 class ExecutionResult:
     """Execution result information."""
 
