@@ -45,9 +45,14 @@ class Port:
                  name: str = '',
                  title: str = '',
                  value: Any = None,
+                 value_format: str = '',
                  node: 'node.Node' = None,
                  visibility: PortVisibility = PortVisibility.Visible):
+        self._title = title
+        self._connections: Set['Port'] = weakref.WeakSet()
+
         self.annotation = annotation
+        self.value_format = value_format
         self.visibility = visibility
         self.name = name
         self.default = default
@@ -69,9 +74,6 @@ class Port:
         except TypeError:
             self.is_enum = False
 
-        self._title = title
-        self._connections: Set['Port'] = weakref.WeakSet()
-
         if isinstance(value, Port):
             self._local_value = default
             self.connect(value)
@@ -183,6 +185,14 @@ class Port:
             else:
                 value = self.annotation(value)
 
+        elif self.annotation is bytes and isinstance(value, str):
+            if self.value_format == 'hex':
+                value = bytes.fromhex(value)
+            elif self.value_format == 'binary':
+                value = int(value, 2).to_bytes((len(value) + 7) // 8, byteorder='big')
+            else:
+                value = value.encode()
+
         self._local_value = value
 
     @property
