@@ -1,11 +1,10 @@
 """Defines model schema files."""
+import dataclasses
 import enum
 import inspect
 import typing
 from typing import Dict, Set, Type, TYPE_CHECKING, Optional
 
-import attr
-
 from mason import callbacks
 from mason import port
 
@@ -20,7 +19,7 @@ class NodeShape(enum.Enum):
     Round = 'round'
 
 
-@attr.s(auto_attribs=True, eq=False)
+@dataclasses.dataclass(eq=False)
 class Schema:
     """Define schema properties."""
 
